cgexplore.forcefields.MartiniSystem
===================================

.. currentmodule:: cgexplore.forcefields

.. autoclass:: MartiniSystem
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~MartiniSystem.get_openmm_system
      ~MartiniSystem.get_openmm_topology
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MartiniSystem.molecule
      ~MartiniSystem.forcefield_terms
      ~MartiniSystem.system_xml
      ~MartiniSystem.topology_itp
      ~MartiniSystem.vdw_bond_cutoff
      ~MartiniSystem.bead_set
   
   